clear all
set mem 300m
use TroopsandCrime.dta
set mat 800
sort cowcode year


xtset cowcode year
tab cowcode, gen(country)
set mat 800



						***TABLE 2 -- CRIME  -- Basic Models***
eststo clear
eststo: quietly reg TFTPOL troops, robust 
eststo: quietly reg ROBPOL troops, robust 
eststo: quietly reg BURPOL troops, robust
eststo: quietly reg DRGPOL troops, robust 
eststo: quietly reg TASPOL troops, robust 
eststo: quietly reg RAPPOL troops, robust 
eststo: quietly reg HOMPOL troops, robust 
esttab _all using base.tex, nogaps label se(a3) b(a3) star(* 0.10 ** 0.05 *** 0.01) scalar(N )  title("Total Reported Crime Rates Using a Standard Regression") replace 



						***TABLE 3 -- CRIME  -- HECKMAN MODELS***					
clear all
set mem 300m
use TroopsandCrime.dta
set mat 800
sort cowcode year

rename tftrep report
 quietly heckman TFTPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Theft) replace
rename report tftrep
rename robrep report
 quietly heckman ROBPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)')  drop(country*) ctitle(Robbery)  append
rename report robrep
rename burrep report
 quietly heckman BURPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Burglary)  append
rename report burrep
rename drgrep report 
 quietly heckman DRGPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Drug)  append
rename report drgrep
rename tasrep report
 quietly heckman TASPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Assault) append
rename report tasrep
rename raprep report 
 quietly heckman RAPPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)')  drop(country*) ctitle(Rape) append
rename report raprep
rename homrep report
 quietly heckman HOMPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') append title() ctitle(Homicide) drop(country*) label
rename report homrep



		/*NEW TABLE 4 -- AGGREGATE CRIME -- HECKMAN MODELS WITH DISAGGREGATED CULTURE 
	  	  VARIABLES AND TROOP INTERACTIONS WITH COW REGION AND GDP*/
clear all
set mem 300m
use use TroopsandCrime.dta
set mat 800
sort cowcode year

rename tftrep report
 quietly heckman TFTPOL troops  cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops_table2, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Theft) replace
rename report tftrep
rename robrep report
 quietly heckman ROBPOL troops  cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*, select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops_table2, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Robbery) append
rename report robrep
rename burrep report
 quietly heckman BURPOL troops  cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* , select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops_table2, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Burglary) append
rename report burrep
rename drgrep report
 quietly heckman DRGPOL troops  cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* , select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops_table2, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Drug) append
rename report drgrep
rename tasrep report
 quietly heckman TASPOL troops  cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* , select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops_table2, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Assaults) append
rename report tasrep
rename raprep report
 quietly heckman RAPPOL troops  cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* , select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops_table2, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Rape) append
rename report raprep
rename homrep report
 quietly heckman HOMPOL troops  cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* , select(report = polity logpop lngdp CIRI lnurban time l.report civilwar) twostep
 outreg2 using troops_table2, excel addstat(N, `e(N)', N (Censored), `e(N_cens)', $\rho$, `e(rho)', $\sigma$, `e(sigma)', $\lambda$, `e(lambda)') drop(country*) ctitle(Homicide) label append
rename report homrep


						/*MARGINAL EFFECTS GRAPHS FOR THEFT AND ASSAULT*/
clear all
set mem 300m
use use TroopsandCrime.dta
set mat 800
sort cowcode year
rename tftrep report

*THEFTS
estsimp reg TFTPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_theft if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 9 polity2 81 logpop 16.27 urbanpercent 38.53 totalunemp 9.10 femlabor 50.33 IMR 9.60 CIRI 7 INJUD 2 civilwar 0 country1-country206 0 country83 1  mills_theft .3595837
setx lngdp 7 
simqi fd(ev) changex(troops 3614 4114 troops_gdp 25298	28798)
setx lngdp 7.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 27105	30855)
setx lngdp 8
simqi fd(ev) changex(troops 3614 4114 troops_gdp 28912	32912)
setx lngdp 8.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 30719	34969)
setx lngdp 9
simqi fd(ev) changex(troops 3614 4114 troops_gdp 32526	37026)
setx lngdp 9.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 34333	39083)
setx lngdp 10
simqi fd(ev) changex(troops 3614 4114 troops_gdp 36140	41140)
setx lngdp 10.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 37947	43197)
setx lngdp 11
simqi fd(ev) changex(troops 3614 4114 troops_gdp 39754	45254)
setx lngdp 11.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 41561	47311)
setx lngdp 12
simqi fd(ev) changex(troops 3614 4114 troops_gdp 43368	49368)
setx lngdp 12.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 45175	51425)
setx lngdp 13
simqi fd(ev) changex(troops 3614 4114 troops_gdp 46982	53482)
setx lngdp 13.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 48789	55539)
setx lngdp 14
simqi fd(ev) changex(troops 3614 4114 troops_gdp 50596	57596)


												/*ASSAULTS*/
rename report tftrep
rename tasrep report
estsimp reg TASPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_assault if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 9 polity2 81 logpop 16.27 urbanpercent 38.53 totalunemp 9.10 femlabor 50.33 IMR 9.60 CIRI 7 INJUD 2 civilwar 0 country1-country206 0 country83 1  mills_assault .3626903
setx lngdp 7 
simqi fd(ev) changex(troops 3614 4114 troops_gdp 25298	28798)
setx lngdp 7.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 27105	30855)
setx lngdp 8
simqi fd(ev) changex(troops 3614 4114 troops_gdp 28912	32912)
setx lngdp 8.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 30719	34969)
setx lngdp 9
simqi fd(ev) changex(troops 3614 4114 troops_gdp 32526	37026)
setx lngdp 9.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 34333	39083)
setx lngdp 10
simqi fd(ev) changex(troops 3614 4114 troops_gdp 36140	41140)
setx lngdp 10.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 37947	43197)
setx lngdp 11
simqi fd(ev) changex(troops 3614 4114 troops_gdp 39754	45254)
setx lngdp 11.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 41561	47311)
setx lngdp 12
simqi fd(ev) changex(troops 3614 4114 troops_gdp 43368	49368)
setx lngdp 12.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 45175	51425)
setx lngdp 13
simqi fd(ev) changex(troops 3614 4114 troops_gdp 46982	53482)
setx lngdp 13.5
simqi fd(ev) changex(troops 3614 4114 troops_gdp 48789	55539)
setx lngdp 14
simqi fd(ev) changex(troops 3614 4114 troops_gdp 50596	57596)



clear
import excel "marginal_effects_graph.xlsx", sheet("Sheet1") firstrow
twoway line tmean lngdp || line tlb lngdp, lpattern(dash) || line tub lngdp, lpattern(dash) ///
legend(off) xlabel(7(1)14) xtitle(ln GDP) ytitle(Marginal Effect) yline(0) ///
subtitle(`"(a)"' `"Theft"', size(medsmall) color(black)) legend(off) ///
saving(marginal_effect_theft.gph, replace)

twoway line amean lngdp || line alb lngdp, lpattern(dash) || line aub lngdp, lpattern(dash) ///
legend(off) xlabel(7(1)14)  xtitle(ln GDP) yline(0) ///
subtitle(`"(b)"' `"Assault"', size(medsmall) color(black)) legend(off) ///
saving(marginal_effect_assault.gph, replace)

graph combine marginal_effect_theft.gph marginal_effect_assault.gph, col(2)  xsize(8) ysize(4) title(Marginal Effect of Troops on Theft and Assault Across GDP ,size(normal)) ycommon




					/*Comparing the Marginal Effect of Troops on Assault Across Regions*/
clear all
set mem 300m
use TroopsandCrime.dta
set mat 800
sort cowcode year
				
rename tasrep report
estsimp reg TASPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_assault if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 7 polity2 49 logpop 16.41 urbanpercent 39.2 totalunemp 8.27 femlabor 47.67 IMR 18.97 CIRI 7 INJUD 2 civilwar 0 country1-country206 0 country83 1  mills_assault .5143777
setx lngdp 11.27 
setx troops 3983
												/*Europe*/
	simqi fd(ev) changex(troops 3983 4483 troops_gdp 44888.41 50523.41)
												/*Latin America	*/
	setx cow_region5 1 troops_cow_region5 3983
 	simqi fd(ev) changex(troops 3983 4483 troops_cow_region5 3983 4483 troops_gdp 44888.41 50523.41)
												/*Asia*/
	setx cow_region5 0 troops_cow_region5 0 cow_region2 1 troops_cow_region2 3983
 	simqi fd(ev) changex(troops 3983 4483 troops_cow_region2 3983 4483 troops_gdp 44888.41 50523.41)
												/*Middle East*/
	setx cow_region2 0 troops_cow_region2 0 cow_region4 1 troops_cow_region4 3983
 	simqi fd(ev) changex(troops 3983 4483 troops_cow_region4 3983 4483 troops_gdp 44888.41 50523.41) 
												/*Africa*/
	setx cow_region4 0 troops_cow_region4 0 cow_region1 1 troops_cow_region1 3983
 	simqi fd(ev) changex(troops 3983 4483 troops_cow_region1 3983 4483 troops_gdp 44888.41 50523.41)  		

clear
import excel "Marginal_Effects_Regions.xlsx", sheet("Sheet1") firstrow
graph twoway rcap lb ub countrynum if crime_num == 5 & countrynum~=5, sort || ///
scatter mean countrynum if crime_num == 5 & countrynum~=5, m(O) color(black) sort ///
xlabel(0.5 " " 1 "Europe" 2 "Latin America" 3 "Asia" 4 "Middle East" 4.5 " ", notick) ///
legend(off) xtitle(" " "Region") yline(0) ytitle(Marginal Effect) title(Marginal Effect of Troops on Assault by Region, size(normal))


						/*Marginal Effects on Theft*/			
clear all
set mem 300m
use TroopsandCrime.dta
set mat 800
sort cowcode year
				
rename tftrep report
estsimp reg TFTPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_theft if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 7 polity2 49 logpop 16.47 urbanpercent 39.61 totalunemp 8.49 femlabor 47.96 IMR 18.23 CIRI 7 INJUD 2 civilwar 0 country1-country206 0 country83 1  mills_theft .4960859 
setx lngdp 11.33 
setx troops 4051
						/*Europe*/
	simqi fd(ev) changex(troops 4051 4551 troops_gdp 45897.83 51562.83)
						/*Latin America*/		
	setx cow_region5 1 troops_cow_region5 4051
 	simqi fd(ev) changex(troops 4051 4551 troops_cow_region5 4051 4551 troops_gdp 45897.83 51562.83)
						/*Asia*/
	setx cow_region5 0 troops_cow_region5 0 cow_region2 1 troops_cow_region2 4051
 	simqi fd(ev) changex(troops 4051 4551 troops_cow_region2 4051 4551 troops_gdp 45897.83 51562.83)
						/*Middle East*/
	setx cow_region2 0 troops_cow_region2 0 cow_region4 1 troops_cow_region4 4051
 	simqi fd(ev) changex(troops 4051 4551 troops_cow_region4 4051 4551 troops_gdp 45897.83 51562.83) 
						/*Africa*/
	setx cow_region4 0 troops_cow_region4 0 cow_region1 1 troops_cow_region1 4051
 	simqi fd(ev) changex(troops 4051 4551 troops_cow_region1 4051 4551 troops_gdp 45897.83 51562.83) 
 	
 	
 						/*Marginal Effects on Robbery*/
clear all
set mem 300m
use TroopsandCrime.dta
set mat 800
sort cowcode year
				
rename robrep report
estsimp reg ROBPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_robbery if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 7 polity2 49 logpop 16.47 urbanpercent 39.65 totalunemp 8.53 femlabor 48.07 IMR 17.95 CIRI 7 INJUD 2 civilwar 0 country1-country206 0 country83 1  mills_robbery .463431
setx lngdp 11.36 
setx troops 4066
						/*Europe*/
	simqi fd(ev) changex(troops 4066 4566 troops_gdp 46189.76 51869.76)
						/*Latin America*/
	setx cow_region5 1 troops_cow_region5 4066
 	simqi fd(ev) changex(troops 4066 4566 troops_cow_region5 4066 4566 troops_gdp 46189.76 51869.76)
						/*Asia*/
	setx cow_region5 0 troops_cow_region5 0 cow_region2 1 troops_cow_region2 4066
 	simqi fd(ev) changex(troops 4066 4566 troops_cow_region2 4066 4566 troops_gdp 46189.76 51869.76)
						/*Middle East*/
	setx cow_region2 0 troops_cow_region2 0 cow_region4 1 troops_cow_region4 4066
 	simqi fd(ev) changex(troops 4066 4566 troops_cow_region4 4066 4566 troops_gdp 46189.76 51869.76) 
						/*Africa*/
	setx cow_region4 0 troops_cow_region4 0 cow_region1 1 troops_cow_region1 4066
 	simqi fd(ev) changex(troops 4066 4566 troops_cow_region1 4066 4566 troops_gdp 46189.76 51869.76) 


						/*Marginal Effects on Burglary*/
clear all
set mem 300m
use TroopsandCrime.dta		
set mat 800
sort cowcode year
				
rename burrep report
estsimp reg BURPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_burglary if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 7 polity2 49 logpop 16.30 urbanpercent 41.19 totalunemp 8.50 femlabor 48.76 IMR 15.50 CIRI 7 INJUD 2 civilwar 0 country1-country206 0 country83 1  mills_burglary .5668686
setx lngdp 11.37 
setx troops 3498
						/*Europe*/
	simqi fd(ev) changex(troops 3498 3998 troops_gdp 39772.26 45457.26)
						/*Latin America	*/
	setx cow_region5 1 troops_cow_region5 3498
 	simqi fd(ev) changex(troops 3498 3998 troops_cow_region5 3498 3998 troops_gdp 39772.26 45457.26)
						/*Asia*/
	setx cow_region5 0 troops_cow_region5 0 cow_region2 1 troops_cow_region2 3498
 	simqi fd(ev) changex(troops 3498 3998 troops_cow_region2 3498 3998 troops_gdp 39772.26 45457.26)
						/*Middle East*/
	setx cow_region2 0 troops_cow_region2 0 cow_region4 1 troops_cow_region4 3498
 	simqi fd(ev) changex(troops 3498 3998 troops_cow_region4 3498 3998 troops_gdp 39772.26 45457.26) 
						/*Africa*/
	setx cow_region4 0 troops_cow_region4 0 cow_region1 1 troops_cow_region1 3498
 	simqi fd(ev) changex(troops 3498 3998 troops_cow_region1 3498 3998 troops_gdp 39772.26 45457.26) 

						
						
						/*Marginal Effects on Drugs*/
clear all
set mem 300m
use TroopsandCrime.dta
set mat 800
sort cowcode year
				
rename drgrep report
estsimp reg DRGPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_drug if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 7 polity2 49 logpop 16.40 urbanpercent 39.45 totalunemp 8.65 femlabor 47.94 IMR 17.53 CIRI 7 INJUD 2 civilwar 0 country1-country206 0 country83 1 mills_drug .4633315
setx lngdp 11.32 
setx troops 4226
						/*Europe*/
	simqi fd(ev) changex(troops 4226 4726 troops_gdp 47838.32 53498.32)
						/*Latin America*/
	setx cow_region5 1 troops_cow_region5 4226
 	simqi fd(ev) changex(troops 4226 4726 troops_cow_region5 4226 4726 troops_gdp 47838.32 53498.32)
						/*Asia*/
	setx cow_region5 0 troops_cow_region5 0 cow_region2 1 troops_cow_region2 4226
 	simqi fd(ev) changex(troops 4226 4726 troops_cow_region2 4226 4726 troops_gdp 47838.32 53498.32)
						/*Middle East*/
	setx cow_region2 0 troops_cow_region2 0 cow_region4 1 troops_cow_region4 4226
 	simqi fd(ev) changex(troops 4226 4726 troops_cow_region4 4226 4726 troops_gdp 47838.32 53498.32) 
						/*Africa*/
	setx cow_region4 0 troops_cow_region4 0 cow_region1 1 troops_cow_region1 4226
 	simqi fd(ev) changex(troops 4226 4726 troops_cow_region1 4226 4726 troops_gdp 47838.32 53498.32) 



						/*Marginal Effects on Rape*/
clear all
set mem 300m
use TroopsandCrime.dta			
set mat 800
sort cowcode year
				
rename raprep report
estsimp reg RAPPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_drug if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 7 polity2 49 logpop 16.46 urbanpercent 39.11 totalunemp 8.54 femlabor 47.79 IMR 18.92 CIRI 7 INJUD 2 civilwar 0 country1-country206 0 country83 1 mills_drug .5666723
setx lngdp 11.28 
setx troops 4058

						/*Europe*/
	simqi fd(ev) changex(troops 4058 4558 troops_gdp 45774.24 51414.24)
						/*Latin America*/
	setx cow_region5 1 troops_cow_region5 4058
 	simqi fd(ev) changex(troops 4058 4558 troops_cow_region5 4058 4558 troops_gdp 45774.24 51414.24)
						/*Asia*/
	setx cow_region5 0 troops_cow_region5 0 cow_region2 1 troops_cow_region2 4058
 	simqi fd(ev) changex(troops 4058 4558 troops_cow_region2 4058 4558 troops_gdp 45774.24 51414.24)
						/*Middle East*/
	setx cow_region2 0 troops_cow_region2 0 cow_region4 1 troops_cow_region4 4058
 	simqi fd(ev) changex(troops 4058 4558 troops_cow_region4 4058 4558 troops_gdp 45774.24 51414.24) 
						/*Africa*/
	setx cow_region4 0 troops_cow_region4 0 cow_region1 1 troops_cow_region1 4058
 	simqi fd(ev) changex(troops 4058 4558 troops_cow_region1 4058 4558 troops_gdp 45774.24 51414.24) 



						/*Marginal Effects on Homicide*/
clear all
set mem 300m
use TroopsandCrime.dta
set mat 800
sort cowcode year
				
rename homrep report
estsimp reg HOMPOL troops cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5 troops_gdp polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country* mills_homicide if report == 1 
setx (cow_region1 cow_region2 cow_region4 cow_region5 troops_cow_region1 troops_cow_region2 troops_cow_region4 troops_cow_region5) 0 polity 7 polity2 49 logpop 16.47 urbanpercent 35.28 totalunemp 8.68 femlabor 47.27 IMR 21.03 CIRI 6 INJUD 2 civilwar 0 country1-country206 0 country83 1 mills_homicide .6251102
setx lngdp 11.17 
setx troops 4282

					/*Europe*/
	simqi fd(ev) changex(troops 4282 4782 troops_gdp 47829.94 53414.94)
					/*Latin America*/
	setx cow_region5 1 troops_cow_region5 4282
 	simqi fd(ev) changex(troops 4282 4782 troops_cow_region5 4282 4782 troops_gdp 47829.94 53414.94)
					/*Asia*/
	setx cow_region5 0 troops_cow_region5 0 cow_region2 1 troops_cow_region2 4282
 	simqi fd(ev) changex(troops 4282 4782 troops_cow_region2 4282 4782 troops_gdp 47829.94 53414.94)
					*Middle East*/
	setx cow_region2 0 troops_cow_region2 0 cow_region4 1 troops_cow_region4 4282
 	simqi fd(ev) changex(troops 4282 4782 troops_cow_region4 4282 4782 troops_gdp 47829.94 53414.94) 
					/*Africa*/
	setx cow_region4 0 troops_cow_region4 0 cow_region1 1 troops_cow_region1 4282
 	simqi fd(ev) changex(troops 4282 4782 troops_cow_region1 4282 4782 troops_gdp 47829.94 53414.94) 


							/*Graphing 6 Remaining Crime Variables*/

clear
import excel "Marginal_Effects_Regions.xlsx", sheet("Sheet1") firstrow
graph twoway rcap lb ub countrynum if crime_num == 1 & countrynum~=5, sort || ///
scatter mean countrynum if crime_num == 1 & countrynum~=5, m(O) color(black) sort ///
xlabel(0.5 " " 1 "Europe" 2 "Latin America" 3 "Asia" 4 "Middle East" 4.5 " ", notick) ///
legend(off) xtitle(" ")  yline(0)  title("(a)" "Theft", size(normal)) ///
saving(theft_graph.gph, replace)

graph twoway rcap lb ub countrynum if crime_num == 2 & countrynum~=5, sort || ///
scatter mean countrynum if crime_num == 2 & countrynum~=5, m(O) color(black) sort ///
xlabel(0.5 " " 1 "Europe" 2 "Latin America" 3 "Asia" 4 "Middle East" 4.5 " ", notick) ///
legend(off) xtitle(" ")  yline(0)  title("(b)" "Robbery", size(normal)) ///
saving(robbery_graph.gph, replace)

graph twoway rcap lb ub countrynum if crime_num == 3 & countrynum~=5, sort || ///
scatter mean countrynum if crime_num == 3 & countrynum~=5, m(O) color(black) sort ///
xlabel(0.5 " " 1 "Europe" 2 "Latin America" 3 "Asia" 4 "Middle East" 4.5 " ", notick) ///
legend(off) xtitle(" ")  yline(0)  title("(c)" "Burglary", size(normal)) ///
saving(burglary_graph.gph, replace)

graph twoway rcap lb ub countrynum if crime_num == 4 & countrynum~=5, sort || ///
scatter mean countrynum if crime_num == 4 & countrynum~=5, m(O) color(black) sort ///
xlabel(0.5 " " 1 "Europe" 2 "Latin America" 3 "Asia" 4 "Middle East" 4.5 " ", notick) ///
legend(off) xtitle(" ")  yline(0)  title("(d)" "Drugs", size(normal)) ///
saving(drugs_graph.gph, replace)

graph twoway rcap lb ub countrynum if crime_num == 5 & countrynum~=5, sort || ///
scatter mean countrynum if crime_num == 5 & countrynum~=5, m(O) color(black) sort ///
xlabel(0.5 " " 1 "Europe" 2 "Latin America" 3 "Asia" 4 "Middle East" 4.5 " ", notick) ///
legend(off) xtitle(" ") yline(0) title("(e)" "Assault", size(normal)) ///
saving(assault_graph.gph, replace)

graph twoway rcap lb ub countrynum if crime_num == 6 & countrynum~=5, sort || ///
scatter mean countrynum if crime_num == 6 & countrynum~=5, m(O) color(black) sort ///
xlabel(0.5 " " 1 "Europe" 2 "Latin America" 3 "Asia" 4 "Middle East" 4.5 " ", notick) ///
legend(off) xtitle(" ")  yline(0)  title("(f)" "Rape", size(normal)) ///
saving(rape_graph.gph, replace)

graph twoway rcap lb ub countrynum if crime_num == 7 & countrynum~=5, sort || ///
scatter mean countrynum if crime_num == 7 & countrynum~=5, m(O) color(black) sort ///
xlabel(0.5 " " 1 "Europe" 2 "Latin America" 3 "Asia" 4 "Middle East" 4.5 " ", notick) ///
legend(off) xtitle(" ")  yline(0)  title("(g)" "Homicide", size(normal)) ///
saving(homicide_graph.gph, replace)

graph combine theft_graph.gph robbery_graph.gph burglary_graph.gph drugs_graph.gph assault_graph.gph rape_graph.gph homicide_graph.gph, col(2) xsize(6) ysize(8) iscale(.45) title(Marginal Effect of Troops by Region ,size(small))


	  	
			
										***APPENDIX TABLE --- LINEAR MODELS***					
clear all
set mem 300m
use TroopsandCrime.dta
set mat 800
sort cowcode year

rename tftrep report
 quietly reg TFTPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_linear, excel   drop(country*) ctitle(Theft) replace
rename report tftrep
rename robrep report
 quietly reg ROBPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_linear, excel    drop(country*) ctitle(Robbery)  append
rename report robrep
rename burrep report
 quietly reg BURPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_linear, excel   drop(country*) ctitle(Burglary)  append
rename report burrep
rename drgrep report 
 quietly reg DRGPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_linear, excel   drop(country*) ctitle(Drug)  append
rename report drgrep
rename tasrep report
 quietly reg TASPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_linear, excel   drop(country*) ctitle(Assault) append
rename report tasrep
rename raprep report 
 quietly reg RAPPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_linear, excel    drop(country*) ctitle(Rape) append
rename report raprep
rename homrep report
 quietly reg HOMPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_linear, excel   append title() ctitle(Homicide) drop(country*) label
rename report homrep


						***APPENDIX TABLE, NBREG Models***					
clear all
set mem 300m
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/CMPS Version/CMPS Revised Version/ISAdata.dta"
cd "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/CMPS Version/CMPS Revised Version"
*use "/Users/PLSCMIchaelAllen/Dropbox/Other Work/Flynn - Military Deployments and Crime/Revision Materials/ISAdata.dta"
*cd "/Users/PLSCMIchaelAllen/Dropbox/Other Work/Flynn - Military Deployments and Crime/Revision Materials"
set mat 800
sort cowcode year

rename tftrep report
 quietly nbreg TFTPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_nbreg, excel addstat(N, `e(N)', a, `e(alpha)') drop(country*) ctitle(Theft) replace
rename report tftrep
rename robrep report
 quietly nbreg ROBPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_nbreg, excel addstat(N, `e(N)', a, `e(alpha)')  drop(country*) ctitle(Robbery)  append
rename report robrep
rename burrep report
 quietly nbreg BURPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_nbreg, excel addstat(N, `e(N)', a, `e(alpha)') drop(country*) ctitle(Burglary)  append
rename report burrep
rename drgrep report 
 quietly nbreg DRGPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_nbreg, excel addstat(N, `e(N)', a, `e(alpha)') drop(country*) ctitle(Drug)  append
rename report drgrep
rename tasrep report
 quietly nbreg TASPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_nbreg, excel addstat(N, `e(N)', a, `e(alpha)') drop(country*) ctitle(Assault) append
rename report tasrep
rename raprep report 
 quietly nbreg RAPPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_nbreg, excel addstat(N, `e(N)', a, `e(alpha)')  drop(country*) ctitle(Rape) append
rename report raprep
rename homrep report
 quietly nbreg HOMPOL troops polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI INJUD civilwar country*
 outreg2 using troops_nbreg, excel addstat(N, `e(N)', a, `e(alpha)') append title() ctitle(Homicide) drop(country*) label
rename report homrep

	
	  		
		
	  		
	  		
			/*GRAPHING INTERACTIVE EFFECT OF TROOPS AND GDP*/

			*THEFT MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interactive_Effects.dta"
graph twoway rcap ub lb gdp if crime==1, lcolor(black) sort ///
|| scatter effect gdp if crime == 1,  m(D) color(black) sort ///
graphregion(color(white)) xlabel(-1.5 " " -1 "1 Std. Dev. Below" -.5 " " 0 "Mean" .5 " " 1 "1 Std. Dev. Above" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///
xtitle("GDP")	xscale() ///
yline(0) scheme(s2mono) ytitle("Interactive Effect of Troops and GDP")
			
			*ROBBERY MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interactive_Effects.dta"
graph twoway rcap ub lb gdp if crime==2, lcolor(black) sort ///
|| scatter effect gdp if crime == 2,  m(D) color(black) sort ///
graphregion(color(white)) xlabel(-1.5 " " -1 "1 Std. Dev. Below" -.5 " " 0 "Mean" .5 " " 1 "1 Std. Dev. Above" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///
xtitle("GDP")	xscale() ///
yline(0) scheme(s2mono) ytitle("Interactive Effect of Troops and GDP")			
			
			*BURGLARY MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interactive_Effects.dta"
graph twoway rcap ub lb gdp if crime==3, lcolor(black) sort ///
|| scatter effect gdp if crime == 3,  m(D) color(black) sort ///
graphregion(color(white)) xlabel(-1.5 " " -1 "1 Std. Dev. Below" -.5 " " 0 "Mean" .5 " " 1 "1 Std. Dev. Above" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///
xtitle("GDP")	xscale() ///
yline(0) scheme(s2mono) ytitle("Interactive Effect of Troops and GDP")

			*DRUG MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interactive_Effects.dta"
graph twoway rcap ub lb gdp if crime==4, lcolor(black) sort ///
|| scatter effect gdp if crime == 4,  m(D) color(black) sort ///
graphregion(color(white)) xlabel(-1.5 " " -1 "1 Std. Dev. Below" -.5 " " 0 "Mean" .5 " " 1 "1 Std. Dev. Above" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///
xtitle("GDP")	xscale() ///
yline(0) scheme(s2mono) ytitle("Interactive Effect of Troops and GDP")

			*ASSAULTS MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interactive_Effects.dta"
graph twoway rcap ub lb gdp if crime==5, lcolor(black) sort ///
|| scatter effect gdp if crime == 5,  m(D) color(black) sort ///
graphregion(color(white)) xlabel(-1.5 " " -1 "1 Std. Dev. Below" -.5 " " 0 "Mean" .5 " " 1 "1 Std. Dev. Above" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///
xtitle("GDP")	xscale() ///
yline(0) scheme(s2mono) ytitle("Interactive Effect of Troops and GDP")

			*RAPE MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interactive_Effects.dta"
graph twoway rcap ub lb gdp if crime==6, lcolor(black) sort ///
|| scatter effect gdp if crime == 6,  m(D) color(black) sort ///
graphregion(color(white)) xlabel(-1.5 " " -1 "1 Std. Dev. Below" -.5 " " 0 "Mean" .5 " " 1 "1 Std. Dev. Above" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///
xtitle("GDP")	xscale() ///
yline(0) scheme(s2mono) ytitle("Interactive Effect of Troops and GDP")

			*HOMICIDE MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interactive_Effects.dta"
graph twoway rcap ub lb gdp if crime==7, lcolor(black) sort ///
|| scatter effect gdp if crime == 7,  m(D) color(black) sort ///
graphregion(color(white)) xlabel(-1.5 " " -1 "1 Std. Dev. Below" -.5 " " 0 "Mean" .5 " " 1 "1 Std. Dev. Above" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///
xtitle("GDP")	xscale() ///
yline(0) scheme(s2mono) ytitle("Interactive Effect of Troops and GDP")


			/*GRAPHING INTERACTIVE EFFECT OF TROOPS AND NON-WESTERN STATES*/
			*THEFT MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interaction_Effects_NonWestern.dta"
graph twoway rcap ub lb nonwestern if crime==1	, lcolor(black) ///
|| scatter effect nonwestern if crime==1, m(D) color(black) ///
graphregion(color(white)) xlabel(-.5 " " 0 "Western" .5 " " 1 "Non-Western" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///	
xtitle("") xscale() ///
scheme(s2mono) ytitle("Interaction Effect of Troops and Non-Western") 
graph export NW_Interactive_Effect_Theft.pdf, replace

			*ROBBERY MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interaction_Effects_NonWestern.dta"
graph twoway rcap ub lb nonwestern if crime==2	, lcolor(black) ///
|| scatter effect nonwestern if crime==2, m(D) color(black) ///
graphregion(color(white)) xlabel(-.5 " " 0 "Western" .5 " " 1 "Non-Western" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///	
xtitle("") xscale() ///
yline(0) scheme(s2mono) ytitle("Interaction Effect of Troops and Non-Western")
graph export NW_Interactive_Effect_Robbery.pdf, replace

			*BURGLARY MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interaction_Effects_NonWestern.dta"
graph twoway rcap ub lb nonwestern if crime==3	, lcolor(black) ///
|| scatter effect nonwestern if crime==3, m(D) color(black) ///
graphregion(color(white)) xlabel(-.5 " " 0 "Western" .5 " " 1 "Non-Western" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///	
xtitle("") xscale() ///
yline(0) scheme(s2mono) ytitle("Interaction Effect of Troops and Non-Western")
graph export NW_Interactive_Effect_Burglary.pdf, replace

			*DRUG MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interaction_Effects_NonWestern.dta"
graph twoway rcap ub lb nonwestern if crime==4	, lcolor(black) ///
|| scatter effect nonwestern if crime==4, m(D) color(black) ///
graphregion(color(white)) xlabel(-.5 " " 0 "Western" .5 " " 1 "Non-Western" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///	
xtitle("") xscale() ///
yline(0) scheme(s2mono) ytitle("Interaction Effect of Troops and Non-Western")
graph export NW_Interactive_Effect_Drug.pdf, replace


			*ASSAULT MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interaction_Effects_NonWestern.dta"
graph twoway rcap ub lb nonwestern if crime==5	, lcolor(black) ///
|| scatter effect nonwestern if crime==5, m(D) color(black) ///
graphregion(color(white)) xlabel(-.5 " " 0 "Western" .5 " " 1 "Non-Western" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///	
xtitle("") xscale() ///
yline(0) scheme(s2mono) ytitle("Interaction Effect of Troops and Non-Western")
graph export NW_Interactive_Effect_Assault.pdf, replace


			*RAPE MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interaction_Effects_NonWestern.dta"
graph twoway rcap ub lb nonwestern if crime==6	, lcolor(black) ///
|| scatter effect nonwestern if crime==6, m(D) color(black) ///
graphregion(color(white)) xlabel(-.5 " " 0 "Western" .5 " " 1 "Non-Western" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///	
xtitle("") xscale() ///
yline(0) scheme(s2mono) ytitle("Interaction Effect of Troops and Non-Western")
graph export NW_Interactive_Effect_Rape.pdf, replace

			*HOMICIDE MODEL*
clear
use "/Users/michaelflynn/Dropbox/Flynn - Military Deployments and Crime/II Version/Interaction_Effects_NonWestern.dta"
graph twoway rcap ub lb nonwestern if crime==7	, lcolor(black) ///
|| scatter effect nonwestern if crime==7, m(D) color(black) ///
graphregion(color(white)) xlabel(-.5 " " 0 "Western" .5 " " 1 "Non-Western" 1.5 " ", notick) legend(lab(1 "95% Confidence Interval")lab(2 "Interactive Effect")order(2 1)) ///	
xtitle("") xscale() ///
yline(0) scheme(s2mono) ytitle("Interaction Effect of Troops and Non-Western")
graph export NW_Interactive_Effect_Homicide.pdf, replace


			/*OUT OF SAMPLE PREDICTIONS FOR THEFT EQUATION AND GDP*/
heckman TFTPOL troops troops_gdp troops_nonwestern non_western polity polity2 logpop urbanpercent totalunemp femlabor lngdp IMR CIRI civilwar country*, select(tftrep = polity logpop lngdp CIRI lnurban time l.tftrep civilwar) twostep
keep country*
range troops 0 100000 1500
gen lngdp = 9.94
gen troops_gdp = troops*lngdp
gen troops_nonwestern = 0
gen non_western = 0
gen polity = 5
gen polity2 = polity^2
gen logpop = 16.2
gen urbanpercent = 32.02
gen totalunemp = 8.72
gen femlabor = 50.47
gen IMR = 49.86
gen CIRI = 4.75
gen civilwar = 0
foreach var of varlist country1-country206 {
replace `var' = 0
}
replace country45 = 1 
predict pr1, xb
predict sterr1, stdp
gen CI_1 = 1.96*sterr1
gen UB1 = pr1 + CI_1
gen LB1 = pr1 - CI_1

replace lngdp = 12.02
replace troops_gdp = troops*lngdp
predict pr2, xb
predict sterr2, stdp
gen CI_2 = 1.96*sterr2
gen UB2 = pr2 + CI_2
gen LB2 = pr2 - CI_2
drop if troops==.

twoway line pr1 troops, lcolor(black) || line UB1 troops, lpattern(dash) lcolor(navy) /// 
	|| line LB1 troops , lpattern(dash) lcolor(navy) ///
	|| line pr2 troops, lcolor(black) lpattern(dash) ///
	|| line UB2 troops, lpattern(dash) lcolor(maroon) ///
	|| line LB2 troops, lpattern(dash) lcolor(maroon) ///
		legend(off) graphregion(color(white))




